@@ -8,7 +8,6 @@ env = config.envs.env
 logging=logger.get_logger(name='MLOps')
 
 
-
 def setup(cdf_api_keys=None):
     """
     Set up the model manager. Currently this involves only setting up the CDF
@@ -82,7 +81,6 @@ def find_model_version(model_name, env, metadata):
         -metadata: query to the metadata (dictionary), it can contain a
         'version' key
     """
-    
     file_list = cdf.query_file_versions(
         directory_prefix='/mlops', 
         external_id_prefix=f"{model_name}/{env}",
@@ -146,4 +144,34 @@ def set_up_model_artifact(artifact_folder, model_name):
     
     logging.info("Download serialized model")
     model_id = download_model_version(model_name, env, artifact_folder)
-    return model_id
\ No newline at end of file
+    return model_id
+
+
+def get_model_version_overview(model_name=None, env=None, metadata={}):
+    """
+    Get overview of model artifact versions. 
+
+    Input:
+        -model_name: name of the model or None for any
+        -env: name of the environment ('dev', 'test', 'prod') or None for any
+        -metadata: dictionary with metadata to query
+    
+    Output:
+        - (dataframe) model artifact data (external id, id, etc.)
+    """
+    # All mlops files with right metadata
+    file_list = cdf.query_file_versions(
+        directory_prefix='/mlops', 
+        external_id_prefix=None,
+        uploaded=None,
+        metadata=metadata
+    )
+
+    # query the external id
+    if model_name:
+        index = file_list.externalId.str.contains(model_name + "/")
+        file_list = file_list.loc[index]
+    if env:
+        index = file_list.externalId.str.contains("/" + env + "/")
+        file_list = file_list.loc[index]
+    return file_list
\ No newline at end of file
